@@ -1,16 +1,9 @@
 import { ComponentType } from 'react';
-import {
-  MatcherConfig,
-  FieldConfig,
-  Field,
-  DataFrame,
-  GrafanaTheme,
-  TimeZone,
-  DataSourceInstanceSettings,
-} from '../types';
+import { MatcherConfig, FieldConfig, Field, DataFrame, GrafanaTheme, TimeZone } from '../types';
 import { InterpolateFunction } from './panel';
 import { StandardEditorProps, FieldConfigOptionsRegistry, StandardEditorContext } from '../field';
 import { OptionsEditorItem } from './OptionsUIRegistryBuilder';
+import { OptionEditorConfig } from './options';
 
 export interface DynamicConfigValue {
   id: string;
@@ -22,6 +15,38 @@ export interface ConfigOverrideRule {
   properties: DynamicConfigValue[];
 }
 
+/**
+ * Describes config override rules created when interacting with Grafana.
+ *
+ * @internal
+ */
+export interface SystemConfigOverrideRule extends ConfigOverrideRule {
+  __systemRef: string;
+}
+
+/**
+ * Guard functionality to check if an override rule is of type {@link SystemConfigOverrideRule}.
+ * It will only return true if the {@link SystemConfigOverrideRule} has the passed systemRef.
+ *
+ * @param ref system override reference
+ * @internal
+ */
+export function isSystemOverrideWithRef<T extends SystemConfigOverrideRule>(ref: string) {
+  return (override: ConfigOverrideRule): override is T => {
+    return (override as T)?.__systemRef === ref;
+  };
+}
+
+/**
+ * Guard functionality to check if an override rule is of type {@link SystemConfigOverrideRule}.
+ * It will return true if the {@link SystemConfigOverrideRule} has any systemRef set.
+ *
+ * @internal
+ */
+export const isSystemOverride = (override: ConfigOverrideRule): override is SystemConfigOverrideRule => {
+  return typeof (override as SystemConfigOverrideRule)?.__systemRef === 'string';
+};
+
 export interface FieldConfigSource<TOptions extends object = any> {
   // Defaults applied to all numeric fields
   defaults: FieldConfig<TOptions>;
@@ -37,7 +62,7 @@ export interface FieldOverrideContext extends StandardEditorContext<any> {
 }
 export interface FieldConfigEditorProps<TValue, TSettings>
   extends Omit<StandardEditorProps<TValue, TSettings>, 'item'> {
-  item: FieldConfigPropertyItem<TValue, TSettings>; // The property info
+  item: FieldConfigPropertyItem<any, TValue, TSettings>; // The property info
   value: TValue;
   context: FieldOverrideContext;
   onChange: (value?: TValue) => void;
@@ -48,51 +73,19 @@ export interface FieldOverrideEditorProps<TValue, TSettings> extends Omit<Standa
   context: FieldOverrideContext;
 }
 
-export interface FieldConfigEditorConfig<TOptions, TSettings = any, TValue = any> {
-  /**
-   * Path of the field config property to control.
-   *
-   * @example
-   * Given field config object of a type:
-   * ```ts
-   * interface CustomFieldConfig {
-   *   a: {
-   *     b: string;
-   *   }
-   * }
-   * ```
-   *
-   * path can be either 'a' or 'a.b'.
-   */
-  path: (keyof TOptions & string) | string;
-  /**
-   * Name of the field config property. Will be displayed in the UI as form element label.
-   */
-  name: string;
-  /**
-   * Description of the field config property. Will be displayed in the UI as form element description.
-   */
-  description?: string;
-  /**
-   * Array of strings representing category of the field config property. First element in the array will make option render as collapsible section.
-   */
-  category?: string[];
-  /**
-   * Custom settings of the editor.
-   */
-  settings?: TSettings;
+export interface FieldConfigEditorConfig<TOptions, TSettings = any, TValue = any>
+  extends OptionEditorConfig<TOptions, TSettings, TValue> {
   /**
    * Function that allows specifying whether or not this field config should apply to a given field.
    * @param field
    */
   shouldApply?: (field: Field) => boolean;
-  defaultValue?: TValue;
-  /**
-   * Function that enables configuration of when field config property editor should be shown based on current panel field config.
-   *
-   * @param currentConfig Current field config values
-   */
-  showIf?: (currentConfig: TOptions) => boolean;
+
+  /** Indicates that option shoukd not be available in the Field config tab */
+  hideFromDefaults?: boolean;
+
+  /** Indicates that option should not be available for the overrides */
+  hideFromOverrides?: boolean;
 }
 
 export interface FieldConfigPropertyItem<TOptions = any, TValue = any, TSettings extends {} = any>
@@ -103,10 +96,16 @@ export interface FieldConfigPropertyItem<TOptions = any, TValue = any, TSettings
   /** true for plugin field config properties */
   isCustom?: boolean;
 
-  // Convert the override value to a well typed value
+  /** Hides option from the Field config tab */
+  hideFromDefaults?: boolean;
+
+  /** Indicates that option should not be available for the overrides */
+  hideFromOverrides?: boolean;
+
+  /** Convert the override value to a well typed value */
   process: (value: any, context: FieldOverrideContext, settings?: TSettings) => TValue | undefined | null;
 
-  // Checks if field should be processed
+  /** Checks if field should be processed */
   shouldApply: (field: Field) => boolean;
 }
 
@@ -114,10 +113,8 @@ export interface ApplyFieldOverrideOptions {
   data?: DataFrame[];
   fieldConfig: FieldConfigSource;
   replaceVariables: InterpolateFunction;
-  getDataSourceSettingsByUid: (uid: string) => DataSourceInstanceSettings | undefined;
   theme: GrafanaTheme;
   timeZone?: TimeZone;
-  autoMinMax?: boolean;
   fieldConfigRegistry?: FieldConfigOptionsRegistry;
 }
 
