@@ -1,6 +1,5 @@
 import { Task, TaskRunner } from './task';
 import { pluginBuildRunner } from './plugin.build';
-import { restoreCwd } from '../utils/cwd';
 import { getPluginJson } from '../../config/utils/pluginValidation';
 import { getPluginId } from '../../config/utils/getPluginId';
 
@@ -9,6 +8,7 @@ import execa = require('execa');
 import path = require('path');
 import fs from 'fs-extra';
 import { getPackageDetails, getGrafanaVersions, readGitLog } from '../../plugins/utils';
+import { buildManifest, signManifest, saveManifest } from '../../plugins/manifest';
 import {
   getJobFolder,
   writeJobStats,
@@ -26,6 +26,9 @@ const rimraf = promisify(rimrafCallback);
 export interface PluginCIOptions {
   finish?: boolean;
   upload?: boolean;
+  signatureType?: string;
+  rootUrls?: string[];
+  maxJestWorkers?: string;
 }
 
 /**
@@ -39,7 +42,7 @@ export interface PluginCIOptions {
  *  Anything that should be put into the final zip file should be put in:
  *   ~/ci/jobs/build_xxx/dist
  */
-const buildPluginRunner: TaskRunner<PluginCIOptions> = async ({ finish }) => {
+const buildPluginRunner: TaskRunner<PluginCIOptions> = async ({ finish, maxJestWorkers }) => {
   const start = Date.now();
 
   if (finish) {
@@ -57,7 +60,7 @@ const buildPluginRunner: TaskRunner<PluginCIOptions> = async ({ finish }) => {
     writeJobStats(start, workDir);
   } else {
     // Do regular build process with coverage
-    await pluginBuildRunner({ coverage: true });
+    await pluginBuildRunner({ coverage: true, maxJestWorkers });
   }
 };
 
@@ -87,11 +90,7 @@ const buildPluginDocsRunner: TaskRunner<PluginCIOptions> = async () => {
   const exe = await execa('cp', ['-rv', docsSrc + '/.', docsDest]);
   console.log(exe.stdout);
 
-  fs.writeFile(path.resolve(docsDest, 'index.html'), `TODO... actually build docs`, err => {
-    if (err) {
-      throw new Error('Unable to docs');
-    }
-  });
+  fs.writeFileSync(path.resolve(docsDest, 'index.html'), `TODO... actually build docs`, { encoding: 'utf-8' });
 
   writeJobStats(start, workDir);
 };
@@ -106,7 +105,7 @@ export const ciBuildPluginDocsTask = new Task<PluginCIOptions>('Build Plugin Doc
  *  2. zip it into packages in `~/ci/packages`
  *  3. prepare grafana environment in: `~/ci/grafana-test-env`
  */
-const packagePluginRunner: TaskRunner<PluginCIOptions> = async () => {
+const packagePluginRunner: TaskRunner<PluginCIOptions> = async ({ signatureType, rootUrls }) => {
   const start = Date.now();
   const ciDir = getCiFolder();
   const packagesDir = path.resolve(ciDir, 'packages');
@@ -114,7 +113,7 @@ const packagePluginRunner: TaskRunner<PluginCIOptions> = async () => {
   const docsDir = path.resolve(ciDir, 'docs');
   const jobsDir = path.resolve(ciDir, 'jobs');
 
-  fs.exists(jobsDir, jobsDirExists => {
+  fs.exists(jobsDir, (jobsDirExists) => {
     if (!jobsDirExists) {
       throw new Error('You must run plugin:ci-build prior to running plugin:ci-package');
     }
@@ -155,15 +154,19 @@ const packagePluginRunner: TaskRunner<PluginCIOptions> = async () => {
   const pluginJsonFile = path.resolve(distContentDir, 'plugin.json');
   const pluginInfo = getPluginJson(pluginJsonFile);
   pluginInfo.info.build = await getPluginBuildInfo();
-  fs.writeFile(pluginJsonFile, JSON.stringify(pluginInfo, null, 2), err => {
-    if (err) {
-      throw new Error('Error writing: ' + pluginJsonFile);
-    }
-  });
+  fs.writeFileSync(pluginJsonFile, JSON.stringify(pluginInfo, null, 2), { encoding: 'utf-8' });
 
-  // Write a manifest.txt file in the dist folder
+  // Write a MANIFEST.txt file in the dist folder
   try {
-    await execa('grabpl', ['build-plugin-manifest', distContentDir]);
+    const manifest = await buildManifest(distContentDir);
+    if (signatureType) {
+      manifest.signatureType = signatureType;
+    }
+    if (rootUrls) {
+      manifest.rootUrls = rootUrls;
+    }
+    const signedManifest = await signManifest(manifest);
+    await saveManifest(distContentDir, signedManifest);
   } catch (err) {
     console.warn(`Error signing manifest: ${distContentDir}`, err);
   }
@@ -171,9 +174,7 @@ const packagePluginRunner: TaskRunner<PluginCIOptions> = async () => {
   console.log('Building ZIP');
   let zipName = pluginInfo.id + '-' + pluginInfo.info.version + '.zip';
   let zipFile = path.resolve(packagesDir, zipName);
-  process.chdir(distDir);
-  await execa('zip', ['-r', zipFile, '.']);
-  restoreCwd();
+  await execa('zip', ['-r', zipFile, '.'], { cwd: distDir });
 
   const zipStats = fs.statSync(zipFile);
   if (zipStats.size < 100) {
@@ -197,19 +198,13 @@ const packagePluginRunner: TaskRunner<PluginCIOptions> = async () => {
     console.log('Creating documentation zip');
     zipName = pluginInfo.id + '-' + pluginInfo.info.version + '-docs.zip';
     zipFile = path.resolve(packagesDir, zipName);
-    process.chdir(docsDir);
-    await execa('zip', ['-r', zipFile, '.']);
-    restoreCwd();
+    await execa('zip', ['-r', zipFile, '.'], { cwd: docsDir });
 
     info.docs = await getPackageDetails(zipFile, docsDir);
   }
 
   p = path.resolve(packagesDir, 'info.json');
-  fs.writeFile(p, JSON.stringify(info, null, 2), err => {
-    if (err) {
-      throw new Error('Error writing package info: ' + p);
-    }
-  });
+  fs.writeFileSync(p, JSON.stringify(info, null, 2), { encoding: 'utf-8' });
 
   // Write the custom settings
   p = path.resolve(grafanaEnvDir, 'custom.ini');
@@ -218,11 +213,7 @@ const packagePluginRunner: TaskRunner<PluginCIOptions> = async () => {
     `[paths] \n` +
     `plugins = ${path.resolve(grafanaEnvDir, 'plugins')}\n` +
     `\n`; // empty line
-  fs.writeFile(p, customIniBody, err => {
-    if (err) {
-      throw new Error('Unable to write: ' + p);
-    }
-  });
+  fs.writeFileSync(p, customIniBody, { encoding: 'utf-8' });
 
   writeJobStats(start, getJobFolder());
 };
@@ -260,11 +251,7 @@ const pluginReportRunner: TaskRunner<PluginCIOptions> = async ({ upload }) => {
 
   // Save the report to disk
   const file = path.resolve(ciDir, 'report.json');
-  fs.writeFile(file, JSON.stringify(report, null, 2), err => {
-    if (err) {
-      throw new Error('Unable to write: ' + file);
-    }
-  });
+  fs.writeFileSync(file, JSON.stringify(report, null, 2), { encoding: 'utf-8' });
 
   const GRAFANA_API_KEY = process.env.GRAFANA_API_KEY;
   if (!GRAFANA_API_KEY) {
