@@ -13,10 +13,10 @@ export default {
 };
 
 export const basic = () => {
-  const intialState: SelectableValue<string> = { label: 'A label', value: 'A value' };
-  const value = object<SelectableValue<string>>('Selected Value:', intialState);
+  const initialState: SelectableValue<string> = { label: 'A label', value: 'A value' };
+  const value = object<SelectableValue<string>>('Selected Value:', initialState);
   const options = object<Array<SelectableValue<string>>>('Options:', [
-    intialState,
+    initialState,
     { label: 'Another label', value: 'Another value' },
   ]);
 
@@ -27,7 +27,7 @@ export const basic = () => {
           <ButtonSelect
             value={value}
             options={options}
-            onChange={value => {
+            onChange={(value) => {
               action('onChanged fired')(value);
               updateValue(value);
             }}
